# Jupyter Community Call December 15th, 2020

**Date:** December 15, 2020, at time 9am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2020-12-15/9:00/Jupyter%20Community%20Call))

[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)
[YouTube Link](https://youtu.be/IlYP6q2H1M8 )

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs, PR of the month

This is a place to make short announcements (without a need for discussion). 

* **[Accessibility testing for docs](https://github.com/pandas-dev/pydata-sphinx-theme/pull/294)**  - _Nick_
  * WIP PR to show a way forward to establish and maintain an accessibility roadmap for Sphinx-based documentation sites
* **[jupyter-starters](https://github.com/deathbeds/jupyterlab-starters) 0.6.0a0 released** - _Nick_ 
  * a tool for defining JSON Schema-based workflows in JupyterLab
* Thanks to everyone who gave feedback on last month's call! - _Isabela_
* Check out @jtp's repos for [Jupyterlab-Classic](https://github.com/jtpio/jupyterlab-classic) and the [p5js notebook](https://github.com/jtpio/p5-notebook). I'm looking forward to sharing with students and teachers at Playfest conference in January. - _Carol_
* Jupyter survey is now live! [Read more](https://blog.jupyter.org/survey-jupyterlab-and-beyond-88c7fbd27a79) and [take the survey](https://www.surveymonkey.com/r/LCB7GBF). - _Isabela_


## Agenda Items

> Add agenda items here **before** the meeting. We will reorganize the agenda so that it fits in the 60m meeting slot.

* **WXYZDVCS** Work-in-progress report on [`wxyz.dvcs`](https://github.com/deathbeds/wxyz), a bridge from Jupyter Widgets to distributed version control - _Nick_
  * _Hopefully_ released this week 🤞, [![Launch Binder]](https://mybinder.org/v2/gh/deathbeds/wxyz/master?urlpath=lab/tree/src/py/wxyz_notebooks/src/wxyz/notebooks/index.ipynb) works though!
* Pierre's notebooks for teaching Python and data science
* [JupyterLab Classic](https://github.com/jtpio/jupyterlab-classic) - *Jeremy*

[binder]: https://mybinder.org/badge_logo.svg

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.
- [deathbeds/importnb](https://github.com/deathbeds/importnb)
- [mwouts/jupytext](https://github.com/mwouts/jupytext)
- [QuantEcon MATLAB-Python-Julia Cheatsheet](https://cheatsheets.quantecon.org)
- [SQLite Jupyter kernel](https://blog.jupyter.org/a-jupyter-kernel-for-sqlite-9549c5dcf551)
- [2i2c](https://2i2c.org/) (brought up around support for JuptyerHubs in education)
- [p5 notebook example](https://p5-notebook.now.sh) (mentioned when talking about JupyterLab Classic)

## Attendees

|   Name             |           Institution            | GitHub Handle                     |
|--------------------|----------------------------------|-----------------------------------|
| Nick Bollweg       | Project Jupyter, GTRI, Deathbeds | @bollwyvl @nrbgt |
| Steven Silvester   | Apple                            | @blink1073 |
| Ryan Spencer       | GTRI                             | @ryspnc |
| Simon Li | University of Dundee | @manics |
| Wayne Decatur      | Upstate Medical University       | @fomightez |
| Pete Blois         | Google Colab                     | @blois      | 
| Pierre-Olivier Simonard | Quansight | @pierrotsmnrd 
| Ryan C. Cooper | University of Connecticut | @cooperrc |
| Raman Tehlan | nteract | [@ramantehlan](https://github.com/ramantehlan) |
| A. T. Darian | Two Sigma | @afshin |
| Jeremy Tuloup | QuantStack | @jtpio
| Damián Avila | UMSI-MADS | @damianavila |
| Tim George | Freelance | @tgeorgeux |
| Gonzalo Peña-Castellanos | Quansight | @goanpeca |
| Zach Sailer | Apple | @Zsailer |
| Carol Willing | Jupyter, noteable| @willingc |
| Sarah Gibson | The Alan Turing Institute | @sgibson91
| Sharan Foga | None | @sharanf
| Tania Allard | --  | @trallard
| Tony Fast | Quansight | @tonyfast
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf
